Analysis Modules
================

Protocol analysis modules provide the core functionality for parsing and analyzing different network protocols.

Base Module
-----------

.. automodule:: mcpcap.modules.base
   :members:
   :undoc-members:
   :show-inheritance:

DNS Module
----------

.. automodule:: mcpcap.modules.dns
   :members:
   :undoc-members:
   :show-inheritance: